@@ -1,3 +1,11 @@
+'''
+A nifty CLI tool to dump an exported file's contents for debugging.
+
+Call it like this::
+
+    python -m haul.cli /path/to/file.haul
+'''
+
 import argparse
 import django
 from django.conf import settings
