@@ -19,6 +19,9 @@ logger.setLevel(logging.DEBUG)
 
 
 class ExportContainer(BaseContainer):
+    '''
+    Your starting point for object export.
+    '''
     __instance_map: Dict[ID, Any]
 
     def __init__(
@@ -32,6 +35,9 @@ class ExportContainer(BaseContainer):
         self.policy = policy or ExportPolicy()
 
     def export_objects(self, objects: Iterable[Model]):
+        '''
+        Serializes objects and adds them to the container.
+        '''
         objects = list(objects)
         if not objects:
             return
@@ -111,6 +117,12 @@ class ExportContainer(BaseContainer):
         return self._objects.values()
 
     def write(self, stream: IO[bytes], format: ContainerFormat = ContainerFormat.YAML, metadata: Any = None):
+        '''
+        Writes the serialized objects from the container into a data stream.
+
+        :param stream: The stream to write into. For ``ContainerFormat.ZIP_*``, has to be seekable.
+        :param metadata: a free-form metadata object that will be stored in the stream. It's available later through :attr:`ImportContainer.metadata`.
+        '''
         stream = UncloseableStream(stream)
         yaml = get_yaml()
         if format == ContainerFormat.YAML:
