@@ -35,8 +35,13 @@ class ImportReport:
 
 
 class ImportContainer(BaseContainer):
+    '''
+    Your starting point for object import.
+    '''
     __instance_map: Dict[ID, Model]
     __discarded_objects: Set[ID]
+
+    #: free-form metadata as stored by :func:`ExportContainer.write`
     metadata: Any = None
 
     def __init__(
@@ -48,13 +53,22 @@ class ImportContainer(BaseContainer):
         super().__init__(exporters, ignore_unknown)
         self.__instance_map = {}
         self.__discarded_objects = set()
-        self.__zipfile = None
         self.__open = False
         self.policy = policy or ImportPolicy()
         self.report = ImportReport()
 
     @contextmanager
     def read(self, stream: BinaryIO):
+        '''
+        Reads a data stream, deserializes objects in it and stores them inside the container.
+
+        This is a context manager which has to be kept open when :func:`import_objects` is called::
+
+            c = ImportContainer(exporters=...)
+            with open(...) as f:
+                with c.read(f):
+                    c.import_objects()
+        '''
         stream.seek(0)
         stream = UncloseableStream(stream)
         reader = BufferedReader(stream)  # type: ignore
@@ -135,6 +149,9 @@ class ImportContainer(BaseContainer):
             self.report.discarded_objects |= set(objects)
 
     def import_objects(self) -> ImportReport:
+        '''
+        Untangles the object graph, relinks objects and imports them into the database.
+        '''
         if not self.__open:
             raise RuntimeError('Container is not open - open a .read() context first')
 
